# tokamunch-pyuda-datasource

![Logo](./docs/logo.png)

Python data source plugin for [tokamunch](https://github.com/stephen-dixon/tokamunch/tree/main).

Available on [pypi](https://pypi.org/project/tokamunch-pyuda-datasource/) to pip install.

--- 

## Quick start

```sh
pip install tokamunch
pip install tokamunch-pyuda-datasource
munchi map --ids blah

```
